@@ -29,7 +29,7 @@
 
 /**
  * Handle to a datasource we can use for the plugins.
- */ 
+ */
 struct EXTRACTOR_Datasource;
 
 
@@ -43,7 +43,8 @@ struct EXTRACTOR_Datasource;
  */
 struct EXTRACTOR_Datasource *
 EXTRACTOR_datasource_create_from_file_ (const char *filename,
-					EXTRACTOR_MetaDataProcessor proc, void *proc_cls);
+                                        EXTRACTOR_MetaDataProcessor proc,
+                                        void *proc_cls);
 
 
 /**
@@ -57,8 +58,9 @@ EXTRACTOR_datasource_create_from_file_ (const char *filename,
  */
 struct EXTRACTOR_Datasource *
 EXTRACTOR_datasource_create_from_buffer_ (const char *buf,
-					  size_t size,
-					  EXTRACTOR_MetaDataProcessor proc, void *proc_cls);
+                                          size_t size,
+                                          EXTRACTOR_MetaDataProcessor proc,
+                                          void *proc_cls);
 
 
 /**
@@ -81,14 +83,14 @@ EXTRACTOR_datasource_destroy_ (struct EXTRACTOR_Datasource *ds);
  */
 ssize_t
 EXTRACTOR_datasource_read_ (void *cls,
-			    void *data,
-			    size_t size);
+                            void *data,
+                            size_t size);
 
 
 /**
  * Seek in the datasource.  Use 'SEEK_CUR' for whence and 'pos' of 0 to
  * obtain the current position in the file.
- * 
+ *
  * @param cls must be a 'struct EXTRACTOR_Datasource'
  * @param pos position to seek (see 'man lseek')o
  * @param whence how to see (absolute to start, relative, absolute to end)
@@ -97,20 +99,20 @@ EXTRACTOR_datasource_read_ (void *cls,
  */
 int64_t
 EXTRACTOR_datasource_seek_ (void *cls,
-			    int64_t pos,
-			    int whence);
+                            int64_t pos,
+                            int whence);
 
 
 /**
  * Determine the overall size of the data source (after compression).
- * 
+ *
  * @param cls must be a 'struct EXTRACTOR_Datasource'
  * @param force force computing the size if it is unavailable
  * @return overall file size, -1 on error or unknown
- */ 
-int64_t 
+ */
+int64_t
 EXTRACTOR_datasource_get_size_ (void *cls,
-				int force);
+                                int force);
 
 
 #endif
