@@ -162,7 +162,7 @@ EXTRACTOR_IPC_shared_memory_create_ (size_t size)
   snprintf (shm->shm_name, MAX_SHM_NAME,
             "%slibextractor-shm-%u-%u",
             tpath, getpid (),
-            (unsigned int) RANDOM ());
+            (unsigned int) random ());
   shm->map = CreateFileMapping (INVALID_HANDLE_VALUE, NULL, PAGE_READWRITE, 0,
                                 size, shm->shm_name);
   shm->ptr = MapViewOfFile (shm->map, FILE_MAP_WRITE, 0, 0, size);
