@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     Copyright (C) 2002, 2003, 2004, 2012, 2017 Vidyut Samanta and Christian Grothoff
+     Copyright (C) 2002, 2003, 2004, 2012, 2017, 2019 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -53,12 +53,12 @@ static struct Matches tmap[] = {
   { "/Keywords (", EXTRACTOR_METATYPE_KEYWORDS },
   { "/Creator (",  EXTRACTOR_METATYPE_CREATED_BY_SOFTWARE },
   { "/Producer (", EXTRACTOR_METATYPE_PRODUCED_BY_SOFTWARE },
-  { NULL, 0 } 
+  { NULL, 0 }
 };
 
 
 /**
- * Parse a "ZZZ" tag.  Specifically, the data may contain a 
+ * Parse a "ZZZ" tag.  Specifically, the data may contain a
  * postscript dictionary with metadata.
  *
  * @param data overall input stream
@@ -71,8 +71,8 @@ static struct Matches tmap[] = {
 static int
 parseZZZ (const char *data,
           size_t pos, size_t len,
-	  EXTRACTOR_MetaDataProcessor proc,
-	  void *proc_cls)
+          EXTRACTOR_MetaDataProcessor proc,
+          void *proc_cls)
 {
   size_t slen;
   size_t end;
@@ -85,37 +85,37 @@ parseZZZ (const char *data,
     return 0;
   pos += slen;
   while (pos < end)
+  {
+    for (i = 0; NULL != tmap[i].text; i++)
     {
-      for (i = 0; NULL != tmap[i].text; i++)
-        {
-          slen = strlen (tmap[i].text);
-          if ( (pos + slen > end) ||
-	       (0 != strncmp (&data[pos], tmap[i].text, slen)) )
-	    continue;
-	  pos += slen;
-	  slen = pos;
-	  while ((slen < end) && (data[slen] != ')'))
-	    slen++;
-	  slen = slen - pos;
-	  {
-	    char value[slen + 1];
-	  
-	    value[slen] = '\0';
-	    memcpy (value, &data[pos], slen);
-	    if (0 != proc (proc_cls, 
-			   "dvi",
-			   tmap[i].type,
-			   EXTRACTOR_METAFORMAT_C_STRING,
-			   "text/plain",
-			   value,
-			   slen + 1))
-	      return 1;
-	  }
-	  pos += slen + 1;
-	  break;
-	}
-      pos++;
+      slen = strlen (tmap[i].text);
+      if ( (pos + slen > end) ||
+           (0 != strncmp (&data[pos], tmap[i].text, slen)) )
+        continue;
+      pos += slen;
+      slen = pos;
+      while ((slen < end) && (data[slen] != ')'))
+        slen++;
+      slen = slen - pos;
+      {
+        char value[slen + 1];
+
+        value[slen] = '\0';
+        memcpy (value, &data[pos], slen);
+        if (0 != proc (proc_cls,
+                       "dvi",
+                       tmap[i].type,
+                       EXTRACTOR_METAFORMAT_C_STRING,
+                       "text/plain",
+                       value,
+                       slen + 1))
+          return 1;
+      }
+      pos += slen + 1;
+      break;
     }
+    pos++;
+  }
   return 0;
 }
 
@@ -153,7 +153,7 @@ getShortAt (const void *data)
 
 
 /**
- * Main entry method for the 'application/x-dvi' extraction plugin.  
+ * Main entry method for the 'application/x-dvi' extraction plugin.
  *
  * @param ec extraction context provided to the plugin
  */
@@ -171,7 +171,7 @@ EXTRACTOR_dvi_extract_method (struct EXTRACTOR_ExtractContext *ec)
   uint64_t size;
   uint64_t off;
   ssize_t iret;
-  
+
   if (40 >= (iret = ec->read (ec->cls, &buf, 1024)))
     return;
   data = buf;
@@ -182,23 +182,25 @@ EXTRACTOR_dvi_extract_method (struct EXTRACTOR_ExtractContext *ec)
   size = ec->get_size (ec->cls);
   if (size > 16 * 1024 * 1024)
     return; /* too large */
+  if (klen + 15 > size)
+    return; /* malformed klen */
   if (NULL == (data = malloc ((size_t) size)))
     return; /* out of memory */
   memcpy (data, buf, iret);
   off = iret;
   while (off < size)
+  {
+    if (0 >= (iret = ec->read (ec->cls, &buf, 16 * 1024)))
     {
-      if (0 >= (iret = ec->read (ec->cls, &buf, 16 * 1024)))
-	{
-	  free (data);
-	  return;
-	}
-      memcpy (&data[off], buf, iret);
-      off += iret;
+      free (data);
+      return;
     }
+    memcpy (&data[off], buf, iret);
+    off += iret;
+  }
   pos = size - 1;
   while ( (223 == data[pos]) &&
-	  (pos > 0) )
+          (pos > 0) )
     pos--;
   if ( (2 != data[pos]) ||
        (pos < 40) )
@@ -220,102 +222,107 @@ EXTRACTOR_dvi_extract_method (struct EXTRACTOR_ExtractContext *ec)
   opos = pos;
   pos = getIntAt (&data[opos + 1]);
   while (1)
-    {
-      if (UINT32_MAX == pos)
-        break;
-      if ( (pos + 45 > size) ||
-	   (pos + 45 < pos) )
-	goto CLEANUP;
-      if (data[pos] != 139)     /* expect 'bop' */
-	goto CLEANUP;
-      pageCount++;
-      opos = pos;
-      pos = getIntAt (&data[opos + 41]);
-      if (UINT32_MAX == pos)
-        break;
-      if (pos >= opos)
-	goto CLEANUP;           /* invalid! */
-    }
+  {
+    if (UINT32_MAX == pos)
+      break;
+    if ( (pos + 45 > size) ||
+         (pos + 45 < pos) )
+      goto CLEANUP;
+    if (data[pos] != 139)       /* expect 'bop' */
+      goto CLEANUP;
+    pageCount++;
+    opos = pos;
+    pos = getIntAt (&data[opos + 41]);
+    if (UINT32_MAX == pos)
+      break;
+    if (pos >= opos)
+      goto CLEANUP;       /* invalid! */
+  }
   /* ok, now we believe it's a dvi... */
   snprintf (pages,
-	    sizeof (pages),
-	    "%u", 
-	    pageCount);
-  if (0 != ec->proc (ec->cls, 
-		     "dvi",
-		     EXTRACTOR_METATYPE_PAGE_COUNT,
-		     EXTRACTOR_METAFORMAT_UTF8,
-		     "text/plain",
-		     pages,
-		     strlen (pages) + 1))
+            sizeof (pages),
+            "%u",
+            pageCount);
+  if (0 != ec->proc (ec->cls,
+                     "dvi",
+                     EXTRACTOR_METATYPE_PAGE_COUNT,
+                     EXTRACTOR_METAFORMAT_UTF8,
+                     "text/plain",
+                     pages,
+                     strlen (pages) + 1))
     goto CLEANUP;
-  if (0 != ec->proc (ec->cls, 
-		     "dvi",
-		     EXTRACTOR_METATYPE_MIMETYPE,
-		     EXTRACTOR_METAFORMAT_UTF8,
-		     "text/plain",
-		     "application/x-dvi",
-		     strlen ("application/x-dvi") + 1))
+  if (0 != ec->proc (ec->cls,
+                     "dvi",
+                     EXTRACTOR_METATYPE_MIMETYPE,
+                     EXTRACTOR_METAFORMAT_UTF8,
+                     "text/plain",
+                     "application/x-dvi",
+                     strlen ("application/x-dvi") + 1))
     goto CLEANUP;
   {
     char comment[klen + 1];
-    
+
     comment[klen] = '\0';
     memcpy (comment, &data[15], klen);
-    if (0 != ec->proc (ec->cls, 
-		       "dvi",
-		       EXTRACTOR_METATYPE_COMMENT,
-		       EXTRACTOR_METAFORMAT_C_STRING,
-		       "text/plain",
-		       comment,
-		       klen + 1))
+    if (0 != ec->proc (ec->cls,
+                       "dvi",
+                       EXTRACTOR_METATYPE_COMMENT,
+                       EXTRACTOR_METAFORMAT_C_STRING,
+                       "text/plain",
+                       comment,
+                       klen + 1))
       goto CLEANUP;
   }
   /* try to find PDF/ps special */
   pos = opos;
   while ( (size >= 100) &&
-	  (pos < size - 100) )
+          (pos < size - 100) )
+  {
+    switch (data[pos])
     {
-      switch (data[pos])
-        {
-        case 139:              /* begin page 'bop', we typically have to skip that one to
+    case 139:                  /* begin page 'bop', we typically have to skip that one to
                                    find the zzz's */
-          pos += 45;            /* skip bop */
-          break;
-        case 239:              /* zzz1 */
-          len = data[pos + 1];
-          if (pos + 2 + len < size)
-            if (0 != parseZZZ ((const char *) data, pos + 2, len, ec->proc, ec->cls))
-	      goto CLEANUP;
-          pos += len + 2;
-          break;
-        case 240:              /* zzz2 */
-          len = getShortAt (&data[pos + 1]);
-          if (pos + 3 + len < size)
-            if (0 != parseZZZ ((const char *) data, pos + 3, len, ec->proc, ec->cls))
-	      goto CLEANUP;
-          pos += len + 3;
-          break;
-        case 241:              /* zzz3, who uses that? */
-          len = (getShortAt (&data[pos + 1])) + 65536 * data[pos + 3];
-          if (pos + 4 + len < size)
-            if (0 != parseZZZ ((const char *) data, pos + 4, len, ec->proc, ec->cls))
-	      goto CLEANUP;
-          pos += len + 4;
-          break;
-        case 242:              /* zzz4, hurray! */
-          len = getIntAt (&data[pos + 1]);
-          if (pos + 1 + len < size)
-            if (0 != parseZZZ ((const char *) data, pos + 5, len, ec->proc, ec->cls))
-	      goto CLEANUP;
-          pos += len + 5;
-          break;
-        default:               /* unsupported opcode, abort scan */
-	  goto CLEANUP;
-        }
+      pos += 45;                /* skip bop */
+      break;
+    case 239:                  /* zzz1 */
+      len = data[pos + 1];
+      if ( (pos + 2 + len < size) &&
+           (0 != parseZZZ ((const char *) data, pos + 2, len, ec->proc,
+                           ec->cls)) )
+        goto CLEANUP;
+      pos += len + 2;
+      break;
+    case 240:                  /* zzz2 */
+      len = getShortAt (&data[pos + 1]);
+      if ( (pos + 3 + len < size) &&
+           (0 != parseZZZ ((const char *) data, pos + 3, len, ec->proc,
+                           ec->cls)) )
+        goto CLEANUP;
+      pos += len + 3;
+      break;
+    case 241:                  /* zzz3, who uses that? */
+      len = (getShortAt (&data[pos + 1])) + 65536 * data[pos + 3];
+      if ( (pos + 4 + len < size) &&
+           (0 != parseZZZ ((const char *) data, pos + 4, len, ec->proc,
+                           ec->cls)) )
+        goto CLEANUP;
+      pos += len + 4;
+      break;
+    case 242:                  /* zzz4, hurray! */
+      len = getIntAt (&data[pos + 1]);
+      if ( (pos + 1 + len < size) &&
+           (0 != parseZZZ ((const char *) data, pos + 5, len, ec->proc,
+                           ec->cls)) )
+        goto CLEANUP;
+      pos += len + 5;
+      break;
+    default:                   /* unsupported opcode, abort scan */
+      goto CLEANUP;
     }
- CLEANUP:
+  }
+CLEANUP:
   free (data);
 }
 
+
 /* end of dvi_extractor.c */
