@@ -1,19 +1,34 @@
 #!/bin/sh
 
+set -eu
+
 ZZSTARTSEED=0
 ZZSTOPSEED=100
 ret=0
 # fallbacks for direct, non-"make check" usage
-if test x"$testdatadir" = x""
+if test x"${testdatadir:-NONE}" = xNONE""
 then
   testdatadir=../../test
 fi
-if test x"$bindir" = x""
+if test x"${bindir:-NONE}" = xNONE""
 then
   bindir=`grep "^prefix = " ./Makefile | cut -d ' ' -f 3`
   bindir="$bindir/bin"
 fi
 
+if test ! -x `which zzuf`
+then
+    echo "zzuf not available, not running the test"
+    exit 77
+fi
+
+if test -x `which timeout`
+then
+    TIMEOUT="timeout 15"
+else
+    echo "timeout command not found, will not auto-timeout (may cause hang)"
+    TIMEOUT=""
+fi
 
 for file in $testdatadir/test*
 do
@@ -26,11 +41,11 @@ do
     do
       echo "file $file seed $seed"
       zzuf -c -s $seed cat "$file" > "$tmpfile"
-      if ! "$bindir/extract" -i "$tmpfile" > /dev/null
+      if ! $TIMEOUT $bindir/extract -i "$tmpfile" > /dev/null
       then
         echo "$tmpfile with seed $seed failed"
-	mv $tmpfile $tmpfile.keep
-	ret=1
+  	    mv $tmpfile $tmpfile.keep
+	    ret=1
       fi
       seed=`expr $seed + 1`
     done
