@@ -36,7 +36,7 @@
  * @return -1 on error, otherwise number of bytes read
  */
 static int
-gif_read_func (GifFileType *ft,
+gif_READ_func (GifFileType *ft,
                GifByteType *bt,
                int arg)
 {
@@ -68,13 +68,13 @@ EXTRACTOR_gif_extract_method (struct EXTRACTOR_ExtractContext *ec)
   int et;
   char dims[128];
 #if defined (GIF_LIB_VERSION) || GIFLIB_MAJOR <= 4
-  if (NULL == (gif_file = DGifOpen (ec, &gif_read_func)))
+  if (NULL == (gif_file = DGifOpen (ec, &gif_READ_func)))
     return; /* not a GIF */
 #else
   int gif_error;
 
   gif_error = 0;
-  gif_file = DGifOpen (ec, &gif_read_func, &gif_error);
+  gif_file = DGifOpen (ec, &gif_READ_func, &gif_error);
   if ((gif_file == NULL) || (gif_error != 0))
   {
     if (gif_file != NULL)
