@@ -112,71 +112,73 @@ EXTRACTOR_jpeg_extract_method (struct EXTRACTOR_ExtractContext *ec)
   jpeg_create_decompress (&jds);
   jpeg_save_markers (&jds, JPEG_COM, 1024 * 8);
   while ( (1 == is_jpeg) || (rounds++ < 8) )
+  {
+    if (-1 == (size = ec->read (ec->cls,
+                                &buf,
+                                16 * 1024)))
+      break;
+    if (0 == size)
+      break;
+    jpeg_mem_src (&jds, buf, size);
+    if (0 == is_jpeg)
     {
-      if (-1 == (size = ec->read (ec->cls,
-				  &buf,
-				  16 * 1024)))
-	break;
-      if (0 == size)
-	break;
-      jpeg_mem_src (&jds, buf, size);
-      if (0 == is_jpeg)
-	{
-	  if (JPEG_HEADER_OK == jpeg_read_header (&jds, 1))
-	    is_jpeg = 1; /* ok, really a jpeg, keep going until the end */
-	  continue;
-	}
-      jpeg_consume_input (&jds);
+      if (JPEG_HEADER_OK == jpeg_read_header (&jds, 1))
+        is_jpeg = 1; /* ok, really a jpeg, keep going until the end */
+      continue;
     }
+    jpeg_consume_input (&jds);
+  }
 
   if (1 != is_jpeg)
     goto EXIT;
   if (0 !=
       ec->proc (ec->cls,
-		"jpeg",
-		EXTRACTOR_METATYPE_MIMETYPE,
-		EXTRACTOR_METAFORMAT_UTF8,
-		"text/plain",
-		"image/jpeg",
-		strlen ("image/jpeg") + 1))
+                "jpeg",
+                EXTRACTOR_METATYPE_MIMETYPE,
+                EXTRACTOR_METAFORMAT_UTF8,
+                "text/plain",
+                "image/jpeg",
+                strlen ("image/jpeg") + 1))
     goto EXIT;
   snprintf (format,
-	    sizeof (format),
-	    "%ux%u",
-	    (unsigned int) jds.image_width,
-	    (unsigned int) jds.image_height);
+            sizeof (format),
+            "%ux%u",
+            (unsigned int) jds.image_width,
+            (unsigned int) jds.image_height);
   if (0 !=
       ec->proc (ec->cls,
-		"jpeg",
-		EXTRACTOR_METATYPE_IMAGE_DIMENSIONS,
-		EXTRACTOR_METAFORMAT_UTF8,
-		"text/plain",
-		format,
-		strlen (format) + 1))
+                "jpeg",
+                EXTRACTOR_METATYPE_IMAGE_DIMENSIONS,
+                EXTRACTOR_METAFORMAT_UTF8,
+                "text/plain",
+                format,
+                strlen (format) + 1))
     goto EXIT;
   for (mptr = jds.marker_list; NULL != mptr; mptr = mptr->next)
-    {
-      size_t off;
+  {
+    size_t off;
 
-      if (JPEG_COM != mptr->marker)
-	continue;
-      off = 0;
-      while ( (off < mptr->data_length) &&
-	      (isspace (((const unsigned char *)mptr->data)[mptr->data_length - 1 - off])) )
-	off++;
-      if (0 !=
-	  ec->proc (ec->cls,
-		    "jpeg",
-		    EXTRACTOR_METATYPE_COMMENT,
-		    EXTRACTOR_METAFORMAT_C_STRING,
-		    "text/plain",
-		    (const char *) mptr->data,
-		    mptr->data_length - off))
-	goto EXIT;
-    }
+    if (JPEG_COM != mptr->marker)
+      continue;
+    off = 0;
+    while ( (off < mptr->data_length) &&
+            (isspace (((const unsigned char *) mptr->data)[mptr->data_length
+                                                           - 1 - off])) )
+      off++;
+    if (0 !=
+        ec->proc (ec->cls,
+                  "jpeg",
+                  EXTRACTOR_METATYPE_COMMENT,
+                  EXTRACTOR_METAFORMAT_C_STRING,
+                  "text/plain",
+                  (const char *) mptr->data,
+                  mptr->data_length - off))
+      goto EXIT;
+  }
 
- EXIT:
+EXIT:
   jpeg_destroy_decompress (&jds);
 }
 
+
 /* end of jpeg_extractor.c */
