@@ -106,7 +106,7 @@ pipe_feeder (void *args)
     while ( (0 == p->shutdown) &&
             (done < rret) )
     {
-      if (-1 == (wret = WRITE (p->pi[1],
+      if (-1 == (wret = write (p->pi[1],
                                &buf[done],
                                rret - done)))
       {
@@ -119,7 +119,7 @@ pipe_feeder (void *args)
     if (done != rret)
       break;
   }
-  CLOSE (p->pi[1]);
+  close (p->pi[1]);
   return NULL;
 }
 
@@ -272,8 +272,8 @@ EXTRACTOR_rpm_extract_method (struct EXTRACTOR_ExtractContext *ec)
     return;
   if (0 != pthread_mutex_init (&parg.lock, NULL))
   {
-    CLOSE (parg.pi[0]);
-    CLOSE (parg.pi[1]);
+    close (parg.pi[0]);
+    close (parg.pi[1]);
     return;
   }
   if (0 != pthread_create (&pthr,
@@ -282,8 +282,8 @@ EXTRACTOR_rpm_extract_method (struct EXTRACTOR_ExtractContext *ec)
                            &parg))
   {
     pthread_mutex_destroy (&parg.lock);
-    CLOSE (parg.pi[0]);
-    CLOSE (parg.pi[1]);
+    close (parg.pi[0]);
+    close (parg.pi[1]);
     return;
   }
   rpmlogSetCallback (&discard_log_callback, NULL);
@@ -416,7 +416,7 @@ END:
   sig.sa_handler = SIG_IGN;
   sigaction (SIGALRM, &sig, &old);
   parg.shutdown = 1;
-  CLOSE (parg.pi[0]);
+  close (parg.pi[0]);
   Fclose (fdi);
   pthread_kill (pthr, SIGALRM);
   pthread_join (pthr, &unused);
