@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the MAN testcase.
  *
@@ -37,49 +36,48 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData man_extract_sol[] =
+  struct SolutionData man_extract_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_TITLE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"EXTRACT",
-	strlen ("EXTRACT") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_SECTION,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	_("Commands"),
-	strlen (_("Commands")) + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_MODIFICATION_DATE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"Aug 7, 2012",
-	strlen ("Aug 7, 2012") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_SOURCE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	_("libextractor 0.7.0"),
-	strlen (_("libextractor 0.7.0")) + 1,
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
+      EXTRACTOR_METATYPE_TITLE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "EXTRACT",
+      strlen ("EXTRACT") + 1,
+      0
+    },
     {
-      { "testdata/man_extract.1",
-	man_extract_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_SECTION,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      _ ("Commands"),
+      strlen (_ ("Commands")) + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_MODIFICATION_DATE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "Aug 7, 2012",
+      strlen ("Aug 7, 2012") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_SOURCE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      _ ("libextractor 0.7.0"),
+      strlen (_ ("libextractor 0.7.0")) + 1,
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/man_extract.1",
+      man_extract_sol },
+    { NULL, NULL }
+  };
   return ET_main ("man", ps);
 }
 
+
 /* end of test_man.c */
