@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the OGG testcase.
  *
@@ -37,57 +36,56 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData courseclear_sol[] =
+  struct SolutionData courseclear_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_MIMETYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"application/ogg",
-	strlen ("application/ogg") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_VENDOR,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"Xiphophorus libVorbis I 20010813",
-	strlen ("Xiphophorus libVorbis I 20010813") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_TITLE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"xoc_SMW_06_courseclear",
-	strlen ("xoc_SMW_06_courseclear") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_ARTIST,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"XOC",
-	strlen ("XOC") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_TRACK_NUMBER,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"6",
-	strlen ("6") + 1,
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
+      EXTRACTOR_METATYPE_MIMETYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "application/ogg",
+      strlen ("application/ogg") + 1,
+      0
+    },
     {
-      { "testdata/ogg_courseclear.ogg",
-	courseclear_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_VENDOR,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "Xiphophorus libVorbis I 20010813",
+      strlen ("Xiphophorus libVorbis I 20010813") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_TITLE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "xoc_SMW_06_courseclear",
+      strlen ("xoc_SMW_06_courseclear") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_ARTIST,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "XOC",
+      strlen ("XOC") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_TRACK_NUMBER,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "6",
+      strlen ("6") + 1,
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/ogg_courseclear.ogg",
+      courseclear_sol },
+    { NULL, NULL }
+  };
   return ET_main ("ogg", ps);
 }
 
+
 /* end of test_ogg.c */
