@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the RIFF testcase.
  *
@@ -37,41 +36,40 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData riff_flame_sol[] =
+  struct SolutionData riff_flame_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_MIMETYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"video/x-msvideo",
-	strlen ("video/x-msvideo") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_FORMAT,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"codec: cvid, 35 fps, 3143 ms",
-	strlen ("codec: cvid, 35 fps, 3143 ms") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_IMAGE_DIMENSIONS,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"256x240",
-	strlen ("256x240") + 1,
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
+      EXTRACTOR_METATYPE_MIMETYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "video/x-msvideo",
+      strlen ("video/x-msvideo") + 1,
+      0
+    },
     {
-      { "testdata/riff_flame.avi",
-	riff_flame_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_FORMAT,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "codec: cvid, 35 fps, 3143 ms",
+      strlen ("codec: cvid, 35 fps, 3143 ms") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_IMAGE_DIMENSIONS,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "256x240",
+      strlen ("256x240") + 1,
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/riff_flame.avi",
+      riff_flame_sol },
+    { NULL, NULL }
+  };
   return ET_main ("riff", ps);
 }
 
+
 /* end of test_riff.c */
