@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the THUMBNAILFFMPEG testcase.
  *
@@ -37,17 +36,16 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData thumbnailffmpeg_video_sol[] =
-    {
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
-    {
-      { "testdata/thumbnailffmpeg_video.mov",
-	thumbnailffmpeg_video_sol },
-      { NULL, NULL }
-    };
+  struct SolutionData thumbnailffmpeg_video_sol[] = {
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/thumbnailffmpeg_video.mov",
+      thumbnailffmpeg_video_sol },
+    { NULL, NULL }
+  };
   return ET_main ("thumbnailffmpeg", ps);
 }
 
+
 /* end of test_thumbnailffmpeg.c */
