@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the WAV testcase.
  *
@@ -37,55 +36,53 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData wav_noise_sol[] =
+  struct SolutionData wav_noise_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_MIMETYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"audio/x-wav",
-	strlen ("audio/x-wav") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_RESOURCE_TYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"1000 ms, 48000 Hz, mono",
-	strlen ("1000 ms, 48000 Hz, mono") + 1,
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct SolutionData wav_alert_sol[] =
+      EXTRACTOR_METATYPE_MIMETYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "audio/x-wav",
+      strlen ("audio/x-wav") + 1,
+      0
+    },
     {
-      { 
-	EXTRACTOR_METATYPE_MIMETYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"audio/x-wav",
-	strlen ("audio/x-wav") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_RESOURCE_TYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"525 ms, 22050 Hz, mono",
-	strlen ("525 ms, 22050 Hz, mono") + 1,
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
+      EXTRACTOR_METATYPE_RESOURCE_TYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "1000 ms, 48000 Hz, mono",
+      strlen ("1000 ms, 48000 Hz, mono") + 1,
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct SolutionData wav_alert_sol[] = {
     {
-      { "testdata/wav_noise.wav",
-	wav_noise_sol },
-      { "testdata/wav_alert.wav",
-	wav_alert_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_MIMETYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "audio/x-wav",
+      strlen ("audio/x-wav") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_RESOURCE_TYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "525 ms, 22050 Hz, mono",
+      strlen ("525 ms, 22050 Hz, mono") + 1,
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/wav_noise.wav",
+      wav_noise_sol },
+    { "testdata/wav_alert.wav",
+      wav_alert_sol },
+    { NULL, NULL }
+  };
   return ET_main ("wav", ps);
 }
 
+
 /* end of test_wav.c */
