@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the XM testcase.
  *
@@ -37,49 +36,48 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData xm_diesel_sol[] =
+  struct SolutionData xm_diesel_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_MIMETYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"audio/x-xm",
-	strlen ("audio/x-xm") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_FORMAT_VERSION,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"1.4",
-	strlen ("1.4") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_TITLE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"diesel",
-	strlen ("diesel") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_CREATED_BY_SOFTWARE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"FastTracker v2.00",
-	strlen ("FastTracker v2.00") + 1,
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
+      EXTRACTOR_METATYPE_MIMETYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "audio/x-xm",
+      strlen ("audio/x-xm") + 1,
+      0
+    },
     {
-      { "testdata/xm_diesel.xm",
-	xm_diesel_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_FORMAT_VERSION,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "1.4",
+      strlen ("1.4") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_TITLE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "diesel",
+      strlen ("diesel") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_CREATED_BY_SOFTWARE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "FastTracker v2.00",
+      strlen ("FastTracker v2.00") + 1,
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/xm_diesel.xm",
+      xm_diesel_sol },
+    { NULL, NULL }
+  };
   return ET_main ("xm", ps);
 }
 
+
 /* end of test_xm.c */
